
# Minio-hung: Print your buckets and .csv files from Minio
## Powered by Ly Duc Hung (FPT Infomation System)

### Bản update nho nhỏ bớt cục súc hơn & bớt mất dạy hơn (Còn nếu bạn chưa biết thì oke bỏ qua đi đừng quan tâm làm gì).

# How to install?
```
pip install Minio-hung
```
## or

Windows
```
py -m pip install Minio-hung
```
Linux/Mac OS
```
python3 -m pip install Minio-hung
```

# What's in package?
```
minio_hung
```

# How to use Minio-hung?

## You can use to one of codes below here:

## Print list buckets in Minio

ACCESS_KEY: Access key in your Services Account.

SECRET_KEY: Secret key in your Services Account.

BUCKET_NAME: Your Bucket name.

OBJECT_NAME: The Object name in your Bucket.

```
#1
import minio_hung

minio_hung.read_list(ACCESS_KEY, PRIVATE_KEY)



#2
from minio_hung import read_list

read_list(ACCESS_KEY, PRIVATE_KEY)

```


## Print .csv file from Minio

### Print .txt file

```
#1
import minio_hung

minio_hung.readtext(ACCESS_KEY, SECRET_KEY, BUCKET_NAME, OBJECT_NAME)



#2
from minio_hung import readtext

readtext(ACCESS_KEY, SECRET_KEY, BUCKET_NAME, OBJECT_NAME)

```

### Print .csv file

```
#1
import minio_hung

minio_hung.readcsv(ACCESS_KEY, SECRET_KEY, BUCKET_NAME, OBJECT_NAME)



#2
from minio_hung import readcsv

readcsv(ACCESS_KEY, SECRET_KEY, BUCKET_NAME, OBJECT_NAME)

```

### Print .xlsx file

```
#1
import minio_hung

minio_hung.readexcel(ACCESS_KEY, SECRET_KEY, BUCKET_NAME, OBJECT_NAME)



#2
from minio_hung import readexcel

readexcel(ACCESS_KEY, SECRET_KEY, BUCKET_NAME, OBJECT_NAME)

```

## Write file from Minio

ACCESS_KEY: Access key in your Services Account.

SECRET_KEY: Secret key in your Services Account.

BUCKET_NAME_IN: Your Bucket name (INPUT).

OBJECT_NAME_IN: The Object name in your Bucket (INPUT).

BUCKET_NAME_OUT: Your Bucket name (OUTPUT).

OBJECT_NAME_OUT: The Object name in your Bucket (OUTPUT).


### Write .txt file

```

#1
import minio_hung

minio_hung.writetext(ACCESS_KEY,PRIVATE_KEY,BUCKET_NAME_IN,OBJECT_NAME_IN,BUCKET_NAME_OUT,OBJECT_NAME_OUT)



#2
from minio_hung import writetext

writetext(ACCESS_KEY,PRIVATE_KEY,BUCKET_NAME_IN,OBJECT_NAME_IN,BUCKET_NAME_OUT,OBJECT_NAME_OUT)

```

### Write .csv file

```
#1
import minio_hung

minio_hung.writecsv(ACCESS_KEY,PRIVATE_KEY,BUCKET_NAME_IN,OBJECT_NAME_IN,BUCKET_NAME_OUT,OBJECT_NAME_OUT)



#2
from minio_hung import writecsv

writecsv(ACCESS_KEY,PRIVATE_KEY,BUCKET_NAME_IN,OBJECT_NAME_IN,BUCKET_NAME_OUT,OBJECT_NAME_OUT)

```